<?php
/* ======================================================
 # Virtuemart Sales for Joomla! - v7.1.8 (free version)
 # -------------------------------------------------------
 # For Joomla! CMS (v3.x)
 # Author: Web357 (Yiannis Christodoulou)
 # Copyright (©) 2014-2023 Web357. All rights reserved.
 # License: GNU/GPLv3, http://www.gnu.org/licenses/gpl-3.0.html
 # Website: https:/www.web357.com
 # Demo: https://demo.web357.com/joomla/virtuemart-sales
 # Support: support@web357.com
 # Last modified: Monday 10 July 2023, 03:54:31 AM
 ========================================================= */
// No direct access
defined('_JEXEC') or die;

JLoader::registerPrefix('VMSales', JPATH_SITE . '/components/com_vmsales/');

/**
 * Class VMSalesRouter
 *
 * @since  3.3
 */
class VMSalesRouter extends JComponentRouterBase
{
	/**
	 * Build method for URLs
	 * This method is meant to transform the query parameters into a more human
	 * readable form. It is only executed when SEF mode is switched on.
	 *
	 * @param   array  &$query  An array of URL arguments
	 *
	 * @return  array  The URL arguments to use to assemble the subsequent URL.
	 *
	 * @since   3.3
	 */
	public function build(&$query)
	{
		$segments = array();
		$view     = null;

		if (isset($query['task']))
		{
			$taskParts  = explode('.', $query['task']);
			$segments[] = implode('/', $taskParts);
			$view       = $taskParts[0];
			unset($query['task']);
		}

		if (isset($query['view']))
		{
			$segments[] = $query['view'];
			$view = $query['view'];
			
			unset($query['view']);
		}

		if (isset($query['id']))
		{
			if ($view !== null)
			{
				// If the file exists, let's
				$model = null;
				if (file_exists(JPATH_SITE . '/components/com_vmsales/models/vmsales.php'))
				{
					require_once JPATH_SITE . '/components/com_vmsales/models/vmsales.php';
					$model = JModelLegacy::getInstance('VMSales', 'VMSalesModel');
				}

				if($model !== null)
				{
					$item       = $model->getItem($query['id']);
					$alias      = $model->getAliasFieldNameByView($view);
					$segments[] = (isset($alias)) ? $item->alias : $query['id'];
				}
			}
			else
			{
				$segments[] = $query['id'];
			}

			unset($query['id']);
		}

		return $segments;
	}

	/**
	 * Parse method for URLs
	 * This method is meant to transform the human readable URL back into
	 * query parameters. It is only executed when SEF mode is switched on.
	 *
	 * @param   array  &$segments  The segments of the URL to parse.
	 *
	 * @return  array  The URL attributes to be used by the application.
	 *
	 * @since   3.3
	 */
	public function parse(&$segments)
	{
		$vars = array();

		// View is always the first element of the array
		$vars['view'] = array_shift($segments);

		$model = null;
		if (file_exists(JPATH_SITE . '/components/com_vmsales/models/vmsales.php'))
		{
			require_once JPATH_SITE . '/components/com_vmsales/models/vmsales.php';
			$model = JModelLegacy::getInstance('VMSales', 'VMSalesModel');
		}
		
		while (!empty($segments))
		{
			$segment = array_pop($segments);

			// If it's the ID, let's put on the request
			if (is_numeric($segment))
			{
				$vars['id'] = $segment;
			}
			else
			{
				$id = $model->getItemIdByAlias(str_replace(':', '-', $segment));
				if (!empty($id))
				{
					$vars['id'] = $id;
				}
				else
				{
					$vars['task'] = $vars['view'] . '.' . $segment;
				}
			}
		}

		return $vars;
	}
}